===========
Objects API
===========

.. module:: netsgiro

The objects API is the higher level API. It parses the "OCR" file into an
object structure that for most use cases is more pleasant to work with than the
lower level :doc:`records API <records>`.

See :doc:`the quickstart guide <quickstart>` for an introduction to how to use
the API.


.. autofunction:: parse


Transmission class
==================

.. autoclass:: Transmission
   :members:
   :undoc-members:
   :inherited-members:


Assignment class
================

.. autoclass:: Assignment
   :members:
   :undoc-members:
   :inherited-members:


Transaction classes
===================

.. autoclass:: Agreement
   :members:
   :undoc-members:
   :inherited-members:

.. autoclass:: PaymentRequest
   :members:
   :undoc-members:
   :inherited-members:

.. autoclass:: Transaction
   :members:
   :undoc-members:
   :inherited-members:
